miércoles, 28 de agosto de 2013
AVISO:
Hola, bien, para empezar no quiero quitarles mucho tiempo; les diré que no se si continuar con el fic, con ninguno en realidad, ya que ando con serios problemas existenciales que aun no logro resolver. (Ando medio rara hoy)
Eh estado leyendo otros fics y me eh dado cuenta de que el mio sinceramente es un asco. No sirvo como escritora, odio jodidamente hacer algo de lo que no estoy completamente segura, si empece esto fue para probar que podía hacer y para desahogar mis ansias de conocer y sentir como seria la vida si algo así llegar a ocurrir, ya que, como muchas de nosotras, naturalmente fantaseo demasiado con la época sesentera y el increíble cuarteto que dejo marcada esa partecita de la historia; porque mi estilo de vida es tan patético en estos momentos que fue mi única salida, si no lo hacia mi cordura caería por los suelos.
Ame escribir al principio y seguiré haciéndolo, tal vez con otro fic. Solo que no tengo una idea concreta de como estructurarlo, eso me ocurre con este y mi anterior fic, que no los veo para nada buenos y me desanima mucho. Se que a todas les pasa igual, ya que no todas tenemos la suficiente confianza en lo que hacemos; pero de alguna forma, en el fondo sabemos que cada una tiene un estilo único y diferente que nos hace especiales en lo que hacemos; y que solo necesitamos un empujoncito para alcanzar esa confianza en nosotros mismos.
Por ahora dejare hasta allí mis historias y leeré otras, me estoy poniendo al tanto con unos cuantos libros a ver que se me ocurre, ademas de alimentar mi escuálida materia gris. =) O no lo se, necesito saber lo que opinan o piensan ustedes, ya que adoro compartir mis locuras con chicas tan maravillosas, pero sinceramente me hace falta "valor" o eso creo yo. Escribir por diversión es una cosa; por necesidad muchas veces es indispensable, y por obligación no es lo mismo, realmente te hace sentir fatigada.
Jajaja, ya las dejo de joder con mi malditos párrafos, solo díganme que opinan al respecto. Muchos saludos, besos, golpes o lo que sea que quieran. ¡Solo no me ataquen por favor! Si, se que hay que proponerse terminar lo que se empieza, porque luego se llega a dejar sin terminar cosas mas importantes... ¡Pero! Tal vez en un tiempo me reincorpore con esto de escribir mis propios fics. Gracias por todo (Que puta dramática soy) ¡Ya joder, hasta aquí! Cuídense. =)
-ElizabethMcC-
martes, 20 de agosto de 2013
#5
-(Tn): ¡Idiota!
-Paul: Ya (Tn), ¿Cálmate quieres?
-(Tn): No intentes tranquilizarme ahora McCartney, esto es
muy serio… ¡Estamos en graves problemas! –La chica se encontraba desparramada
en el suelo con mucha sangre saliendo de su cabeza.- No sé si esta desmayada o
muerta… ¡Dime que paso!-Me agache para intentar limpiar la sangre y revisar su
pulso.-¿¡Que crees que hacias!?
-Paul: Lo que paso fue que…
FLASHBACK (Relatado por Paul)
-(Tn): ¿Por qué hiciste eso?-Me dijo apartándose de mí, se
notaba asombrada. Yo sonreí.
-Paul: Quería hacerte sonreír. -Dije para romper tensión, lo
cierto era que no me había aguantado. Ella se encontraba mal por culpa de ese
bastardo, y no me gustaba verla así.
-(Tn): No era necesario besarme…
-Paul: Pues a mí me gusto, ¿y a ti? -Parecía que no le había
gustado para nada y me sentía como un tonto. El esfuerzo que tuve que hacer me
tenía fatigado pero se sentía distinto a
cuando estaba vivo. Me desvanecía un poco, al parecer ella no se dio cuenta.
-(Tn): Emmm pues…Aun no me explico cómo hiciste eso.
-Paul: Jajajajaja, no preguntes, solo agradece. Y por
cierto…tus labios saben a cereza, con vainilla.-Agregué soltando unas risas, el
color de sus mejillas se hizo más notorio. ¡Lo sabía! Le había gustado. Un punto
para McCartney.
-(Tn): Es que…el helado era de cereza con vainilla…
-Paul: Eso lo explica todo. Jajajajaja.-No sé si era el
helado, o ella. –Bésame…Bésame mucho.
-(Tn): Que pesado eres.-Se notaba nerviosa, aunque algo
molesta, su miraba me evitaba ¿Ahora que había echo mal?
Ella no entendía el esfuerzo que me llevo ese acto, era
obvio, aunque podía conectarse con el más allá, seguía estando viva, por eso no
entendía muchas cosas. Sentía que me desaparecería en cualquier momento, pero
no quería irme de su lado.
Nunca bese a nadie luego de mi muerte, pensé que no lo necesitaría,
pero aún quedaba algo humano en mí, algo que me tenía atado a este mundo. Por
una parte, no quería irme.
--------------------------------------------------------------------------------------------
-No puede ser…
-X: ¡Hey! ¿Quién anda allí?
-Frida: ¡Ah! Un guardia. Maldición.
El guardia alumbraba con una linterna buscando a la persona
que recorría la casa, a esas altas horas de la noche era sospechoso. Frida dejo
de observar la ventana sin poder ver nada más que la misteriosa luz; se
escabullía entre los arbustos sigilosamente, espero un rato a que el hombre se
valla. -Que no tenga un perro, que no
tenga un perro, que no tenga un perro.-Decía para sí misma, si cargaba uno
estaba perdida. Pero para su suerte andaba solo. Luego de unos minutos, el
guardia se cansó de buscar y continúo su recorrido nocturno.-Uf…-
Se acercó hasta la puerta con la chaqueta en mano, dudaba de
si entrar o no por lo sucedido. Sin pensarlo más toco el timbre una vez.
-------------------------------------------------------------------------------------------------------------------------------
-------------------------------------------------------------------------------------------------------------------------------
(Relatado por Paul)
-¡Diiing!-Se escuchó un chirrido, supuse que era el timbre,
pero (Tn) frunció el ceño confusa.
-(Tn): ¿Aaah?
-Paul: ¿Qué ocurre?
-(Tn): Yo nunca recibo visitas, ni menos a esta hora…Me
pregunto quién será.
Se levantó del sofá y abrió la puerta unos centímetros.
Parecía ser una chica al oír su voz.
-Frida: Emmm, hola.
-(Tn): Hola… ¿Se te ofrece algo?
-Frida: Si…Bueno, yo soy la chica de la cafetería.
¿Recuerdas? Vine a devolverte esto.-Le extendió la mano enseñándole una
chaqueta.-La encontré en uno de los baños.
-(Tn): ¡Aahh, mi chaqueta! Claro, ya recuerdo. Muchas
gracias pero… ¿Cómo sabias mi dirección?
-Frida: Si…tal vez no lo hayas notado, pero somos vecinas,
vivo aquí al lado. Te vi un par de veces, así que logre reconocerte.
-(Tn): Ahh. Lo siento….es que, no suelo socializar mucho,
apenas llevo un año viviendo aquí y…
-Frida: Lo sé, no te preocupes, yo soy igual.
-(Tn): Que mal educada soy, ven, pasa…-(Tn) abrió la puerta
para que la chica entrara.
-Frida: No quisiera molestar.
-(Tn): ¿Cómo? No…Vivo sola, más bien es un placer. Anda.
-Frida: La verdad te escuche hablar con alguien y
pensé…-¡Nos había oído! (Tn) estaba nerviosa titubeando, buscaba cualquier
excusa.
-(Tn): Ahh…Bueno, yo...veía televisión, creo que el sonido
estaba muy fuerte.
-Frida: Mmmm…Muy bien.
-(Tn): Soy (Tn) Castle.
-Frida: Frida Harrison.
-(Tn): Como George Harrison.-Indico riendo. Yo también me reí
al escuchar eso.
-Frida: ¿También te gustan los Beatles?
-(Tn): ¡Claro! Me encantan.
-Frida: ¿A quién no? Jajajajajaja.
-(Tn): Te congelaras allá afuera, entra de una vez.-La chica
entro, (Tn) le indico sentarse en el sofá a lo que ella accedió. –Preparare té.
Espérame un momento
-Frida: Esta bien.-Sonrió.
(Tn) fue a la cocina, yo la seguí, y quise molestarla un
rato.
-Paul: Que linda invitada tienes.
-(Tn): No molestes Paul, mantente alejado de ella.
-Paul: ¿Celosa?
-(Tn): No. Solo que si ella te llega a ver va a ser un
desastre, ya mucho con lo que paso hace un rato. –Exclamo contrariada.
-Paul: Tranquila, no puede verme.
-(Tn): Eso no lo sé, muchas personas son susceptibles a las
presencias, tal vez no tanto como yo, pero lo hacen. Y no quiero correr
riesgos. Solo desaparece un rato.- ¿Por qué se comportaba así conmigo? A veces
podía ser muy fría y cruel, aunque no la culpo, el mundo la hizo así.
-Paul: Si eso es lo que quieres…-Ya igual me desvanecería,
mi energía se agotaba, y poco a poco fui desmaterializándome. –Tal vez venga
luego.
-(Tn): O.K pero…-Al darse la vuelta ya yo no estaba. Si me
encontraba allí, pero ella no podía verme ni escucharme. Aun no sabía porque
sucedía eso…Solo sé que pasaba. Y que luego de un tiempo podía aparecer otra
vez.
Agarro las dos tazas de té, entregándole una a Frida. Ella
agradeció. Conversaron un largo tiempo. Ya se hacía media noche, no entendía
que tanto hablaban estas chicas. Enserio, siempre me dio curiosidad. ¿Por qué
las mujeres hablan tanto? De un tema saltan al otro como si nada…Eso no había cambiado
a pesar de la época.
Me hacía recordar a las largas conversaciones que Jane tenía
en sus reuniones, a las que yo más que aburrido me apartaba lentamente hasta
salir y fumar algo, simplemente no lo soportaba. Llamaba a John y nos íbamos a
un pub, donde cualquier chica estaba dispuesta a todo. Pobre Jane, ella ni
enterada, al igual que Cynthia; solían ser muy ingenuas. Llegaba como si nada,
con la reunión a punto de terminar, ella me besaba, agradecía y nos íbamos a
dormir. Pero eso acabo ya…Ahora solo tengo recuerdos, como hubiese querido no
hacerle tanto daño. Creo que yo en verdad merecía esto.
--------------------------------------------------------------------------------------------------------
Relatado por (Tn)
-(Tn): ¿Vives sola?
-Frida: Si.
-(Tn): ¿Qué hay de tu familia?
-Frida: No me gusta hablar sobre eso…
-(Tn): Te entiendo, a mí tampoco, lo siento.
-Frida: No te preocupes….-Luego de un silencio, con la
mirada entristecida se decidió a hablar.-Mis padres murieron hace tres años por
cáncer.
-(Tn): ¿Los dos?
-Frida: Si…pero era mejor así, él era un alcohólico y ella
sufría mucho.
-(Tn): Que espantoso….-No sabía cuan parecida a mí era, su
vida había sido difícil también, eso me hizo entrar en confianza con ella,
entendía por todo lo que había pasado.
-Frida: Lo sé. Tuve que dejar el colegio y comenzar a
trabajar.-Dudosa por todo lo que confesaba, dio un sorbo a la última taza de té
y se acomodó en el asiento.-Valla…Que fácil es hablar contigo, normalmente no
hubiese dicho eso a alguien que apenas acabo de conocer. Gracias por escuchar.
-(Tn): No hay de que, no somos tan diferentes ¿Sabes?
-Frida: Supongo que no… ¿Podemos….cambiar de tema?
-(Tn): Oh claro. Mmmm ¿Cuál es tu Beatle favorito?
-Frida: Jajajaja es George. ¿Y el tuyo?
-(Tn): Pues…Siempre ha sido
John.-Menos mal que Paul no estaba cerca, si no me reclamaría todo un mes.
--------------------------------------------------------------------------------------------------------------------
Relatado por Paul
-(Tn): Oh claro. Mmmm ¿Cuál es tu Beatle favorito?
-Frida: Jajajaja es George. ¿Y el tuyo?
-Paul: ¿¡George!? Ya no me caes tan bien… (Tn) será mejor
que digas que yo porque si no…
-(Tn): Pues…Siempre ha sido John.
-Paul: ¿John? ¿¡John!? ¡Traicionera!
-Frida: John es tan sexy…Sabes, Paul nunca me agrado; parece
niña.
-Paul: ¿Y tú que te crees?
-Frida: Aun así era bastante guapo. No lo niego.
-Paul: Aahh ¡Así está mejor!
-(Tn): Jajajajaja, Paul es mi segundo favorito.
-Paul: ¿Segundo? ¡Hey, eso no se vale! ¿Y dónde queda
Ringuis?
-Frida: Pero sin duda los ojos de Ringo eran los más
hermosos, él era el más tierno. Aunque no haya sido el mejor baterista tenía
estilo.
-Paul: Buen punto…
-(Tn): Jajajajaja tienes razón, siempre lo excluían,
pobrecito.
-Paul: ¡Eso no es cierto! Bueno….Un poco pero…
-Frida: Si, emmm…. ¿Puedo usar el baño?
-(Tn): Por supuesto. Queda al principio del pasillo en la
puerta blanca.
-Frida: Gracias.
La chica fue al baño, mientras tanto (Tn) jugaba con las
hojas de té al final de su taza, bostezaba intentado no quedarse dormida, se
veía muy tierna. Frida ya se tardaba mucho, pero cuando salía, sentí que
recobraba mi energía, apareciendo justo delante de ella, ¡Que inoportuno! Nunca
sabia donde volvía a aparecer y tenía que ser exactamente en ese lugar. Note inmediatamente que me había
visto.
Le sonreí cómicamente, sin saber qué hacer. Ella solo abrió
los ojos, muda, se puso totalmente pálida. Rodo los ojos y cayó desmayada directamente
al suelo golpeando primero la cabeza contra la pared, ya que el pasillo era
angosto. Vi como (Tn) se acercaba muy alterada.
---------------------------------------------------------------------------------------------------------
Relatado por (Tn)
Relatado por (Tn)
Oí un golpe muy fuerte proveniente del pasillo, pensé que
algo le había ocurrido a Frida. Salí corriendo hacia allá.
-(Tn): ¿Frida?-Vi el cuerpo inmóvil y me asusté mucho.-
¡Frida! ¡Oh mi Dios!
-Paul: ¡(Tn)!
-(Tn): ¿Paul? ¿¡Que hiciste!?
-Paul: No, yo no hice nada, solo…
-----------------------------------------------------------------------------------------------------
Fin del Flashback.
-(Tn): ¡No puedo creerlo! ¿Qué le voy a decir cuándo
despierte?-Susurraba. La recosté del sofá pasando un pañuelo mojado por su
frente.
-Paul: Dile que se quedó dormida en el baño y se golpeó la
cabeza en el lavamanos.
-(Tn): No, eso no. No lo creerá, ya te vio.
-Paul: Mmmm ¿tal vez que solo fue su imaginación?
-(Tn): Ella no es tonta.
-Paul: Entonces dile que tienes un primo que es igual a mí.
-(Tn): Si claro…Y yo soy la nieta perdida de John Lennon. No
ayudas.
-Paul: ¡Ahhh, entonces no se! Tú tampoco piensas en nada.
-(Tn): Pero yo no fui la que aparecí de repente en frente de
ella.
-Paul: Tampoco es mi culpa, yo no controlo esta situación
tan fácilmente.
-(Tn): ¡Aaaaaahhh!
-----------------------------------------------------------------------------------------------------
Reincorporándose a la realidad otra vez, abrió los ojos
lentamente, oía muchos murmullos, y entre luces y sombras su vista se adaptó
rápido.
-Frida: ¿Qué…Que paso?-Preguntaba muy confundida, pero al
parecer ninguno de los dos la notaba por la discusión que traíamos.
Frida se levantó del sofá sobándose la cabeza muy aturdida,
sintiendo el líquido viscoso que todavía brotaba levemente de la parte superior
del cráneo. Por la impresión no se percató de quien era el acompañante de su
nueva amiga, y cuando estos se dieron cuenta un silencio estremecedor inundo el
ambiente, nadie decía nada y los tres nos mirábamos estupefactos.
-Pa…Pa….-Pronuncio temblorosa las silabas dos veces más
desplomándose en el sofá de nuevo.
-------------------------------------------------------------------------------------------------------------
-(Tn): ¡Te vio Paul! ¡Te vio!
-Paul: ¡No me digas!
-(Tn): Espera…Creo que está despertando otra vez…-Frida
abrió los ojos, esta vez sentándose de golpe. Un agudo grito de terror
estremeció mis oídos (No era como los que se escuchaban en los conciertos de
los 60’s cuando veían a un Beatle, vivo.)
---------------------------------------------------------------------------------------------------------
-Así que por fin conozco al Beatle perdido. Wow…Nunca creí
que algo así pudiese ocurrir, pero… ¿Tú no eras amigo de Paul y de ellos? ¿Por
qué quieres evitarlo?
-Stuart: Si, eran mis amigos, como olvidarlos. Pero esto no
es por mí, fui enviado por alguien más. Créeme que me encantaría que Paul fuera
libre, es solo que esto ha llegado tan lejos que si se sabe las cosas
cambiarían y no para bien, ¿Te imaginas
cuantos fans enloquecerían? Sería peor que con la muerte de Lennon, en serio,
mucho peor.
-Cosette: Pero tú ya estás muerto, las cosas que sucedan
aquí ya no deberían de importar en la otra vida.
-Stuart: Eso mismo fue lo que pensé, pero yo soy como Paul,
aun no eh podido cruzar esta dimensión, así que tampoco estoy libre.
-Cosette: ¿Y por qué?
-Stuart: Porque quise quedarme con Astrid…Por ella fue que
quede atado a este mundo.
-Cosette: Entiendo, aunque sigo un poco confundida.
-Stuart: Como no se en realidad la forma de liberarme, y han
pasado tantos años, entonces quiero darle una mano a la banda de la que antes
fui miembro, y a mis amigos, por eso tengo que ayudarlos a guardar el secreto y
que el legado Beatle continúe igual, no me imagino cómo reaccionaría el mundo
ante esto, ya que después de todo siguen siendo muy famosos.
-Cosette: ¿Y por qué no solo vas a donde Paul, le dices eso y ya? El entenderá.
-Stuart: Porque los espíritus no pueden comunicarse entre
sí.
-Cosette: Pero yo podría decirle, solo dime donde está.
-Stuart: Él ya tiene un plan Cosette, no te va a escuchar,
además no creo que lo puedas ver, no eres médium ni nada parecido. Dime… ¿Has
visto algún fantasma en tu vida?
-Cosette: No, pero ¿Y cómo a ti si te puedo ver?
-Stuart: Porque mi energía es fuerte, no sé si lo
comprendas, yo dejo que tú me veas. En cambio si estuviera aquí y no quisiera
que me vieses entonces no lo harías. Pero la mayoría de espíritus se esconden
de los vivos.
-Cosette: ¿Y porque yo te tengo que ayudar?
-Stuart: No puedo solo, creo que te harías muy buena amiga
de la chica que está ayudando a Paul, necesito que lo hagas, por The Beatles,
todo debe continuar igual.
-Cosette: Muy bien, si lo que dices es cierto, te ayudare,
todo sea por ti Stuart.
-Stuart: ¡Gracias!
-Cosette: Con una condición...Me tienes que enseñar a
pintar.
-Stuart: Jajajaja con gusto preciosa.
-Cosette: Una pregunta más…
-Stuart: Claro.
-Cosette: ¿Quién te envió?
-Stuart: Eso no te lo puedo decir ahora.
-Cosette: ¿Entonces cuando?
-Stuart: Jajajaja tranquila, luego lo sabrás…-Diciendo esto
se esfumo.
Ella diviso al vacío, esperando algo más, pero no. Sacudió
la cabeza y regreso como pudo al hotel donde se hospedaba, pidiendo
indicaciones a las personas decentes que recorrían las calles.
------------------------------------------------------------------------------------------------------------------------------------
------------------------------------------------------------------------------------------------------------------------------------
-(Tn): Se que es una locura, pero te pido por favor que no
digas nada de esto a nadie.
-Frida: No lo hare.
-(Tn): Promételo.
-Frida: Lo prometo, de veras. Puedes contar conmigo, es más,
te voy a ayudar Paul.
-(Tn): Gracias.
Luego de haberle explicado todo a Frida, ella más calmada se
dispuso a escucharme, observaba a Paul de reojo y en su rostro aun se notaba
asombro y miedo. Un silencio pausado se interponía entre los tres, Paul de pie
con una seriedad notoria, Frida y yo sentadas en la mesa del comedor una de frente
a la otra.
-Frida: Yo lo sabía.
-(Tn): ¿Qué cosa?
-Frida: Lo sospeche.
-(Tn): ¿De qué estás hablando? ¡Frida!
-Frida: Jajajajajajajajaja, siempre lo supe ¡Rayos! Si.
-(Tn): ¡Basta!
-Frida: Lo siento…lo que sucede es que hace unos años hasta
ahora eh estado viendo toda clase de fenómenos extraños por todos lados, veía a
personas que estaban muertas, cosa que nunca había experimentado, y pensé…tal
vez sea un don que tengo o simplemente estoy loca, desquiciada. Pero ahora sé
que no soy la única y eso me tranquiliza, aunque en cierto modo es
atemorizante, el ver a Paul McCartney como un “fantasma” incomoda un poco, sin
embargo algo me decía que el mito era cierto.
-(Tn): Ya se, tuve que acostumbrarme a eso.
-Paul: ¿Entonces me ayudaras?
-Frida: Cla…. ¡Auch!- Cerro sus ojos, apretando los dientes
de dolor.
-(Tn): ¿Te encuentras bien?
-Frida: Mi cabeza, me duele mucho.
-(Tn): Pobrecita.-Le revise la cabeza sobándola
ligeramente.- ¿Ves lo que haces Paul?
-Paul: Ya te dije que no fue mi culpa.
-(Tn): Espera aquí, iré a traerte una pastilla.
-Frida: Esta bien.-Ella me sonrió curiosamente y yo igual.
-(Tn): Tomate esto.-Le indique entregándole un vaso de jugo
y la pastilla.
-Frida: Gracias.-Esta vez me observo cohibida.
-(Tn): ¿Pasa algo?
-Frida: No, nada, es que…no tiene importancia. Gracias por
todo, has sido muy buena conmigo
-(Tn): No hay de qué. –Sonreímos mutuamente con brillo en
nuestros ojos.
Me agradaba bastante esa chica, ¿Sera que había conseguido
una amiga? ¡Perfecto! Aunque me preocupaba lo de Paul, yo sentía que podía
confiar en ella, así que por ese lado estaba tranquila.
viernes, 26 de julio de 2013
#4
-Paul: Linda ropa…
-(Tn): Es día de limpieza. Ando como loca, lo sé, pero no te
burles. -Concentrada en mis labores hogareñas, me disponía a trapear el piso.
El sol brillaba con intensidad, dando a la habitación una luminosidad alegre,
uno de esos pocos días que se ven en Londres.
-Paul: No hay de qué preocuparse. Te ves sexy.-Yo ignore su
comentario.-Esta vez no gritaste, ni dijiste: ¡Paul!-Dijo imitando mi voz.
-(Tn): Es que ya me acostumbre a tus repentinos susurros,
estrellita.-Hice una mueca.
-Paul: ¿Estrellita?
-(Tn): Si…Es tu nuevo apodo ¿Te gusta?
-Paul: Suena muy gay.
-(Tn): Jajajaja, te acostumbraras.-El me miro contrariado.
-Paul: Valla, todo luce reluciente.-Recorrió mi casa
observando a todos lados.- ¿Eres una fanática de la limpieza o algo así?
-(Tn): No, Paul. Por si no lo sabias, la limpieza es algo
que se hace siempre si no quieres vivir en un basurero. Pero claro…Como tú
nunca lo hacías.
-Paul: Si limpiaba…Bueno, ayudaba a mi madre a unas cuantas
cosas…Pero luego me hice famoso y ya no era mi trabajo eso de ser ordenado.
-(Tn): Si, ya veo.
-Paul: Era más divertido el desorden, ya sabes…Vivir en
nuestro propio jugo.
-(Tn): Aaggg, Paul, que asqueroso eres.-Lo mire con
repugnancia.
-Paul: Jajajajaja, aun así me amaban.
-(Tn): Cállate. Voy a vomitar si continúas con tus
comentarios innecesarios.
-Paul: ¿No tenías que ir a la universidad hoy?-Pregunto
recostándose de una silla, y otra vez me invadió esa pregunta… ¿Cómo lo hacía
sin traspasar la silla?
-(Tn): Pues no…Tengo una semana de vacaciones. Ya eh
terminado el primer ciclo.
-Paul: Entonces, no hace mucho que ingresaste…
-(Tn): Como ya te dije, recién el año pasado logre salir del
internado, donde también veía clases. Eso me ayudo a conseguir un puesto en la
carrera de diseño, pero ingrese luego de seis meses.
-Paul: Entonces, ¿Tienes 19 años y ya vives sola?
-(Tn): Eso parece. ¿Y de que te sorprendes? Tú viajaste a
Alemania con una banda de rock antes de cumplir los 19.
-Paul: Buen punto…Pero no estaba solo.
-(Tn): Pero se drogaban, y ni hablar de lo que hacían con
las mujeres.
-Paul: Ok ok ya entendí…Y no me juzgues, ¿o es que tú eres
una santa?
-(Tn): Pues fíjate que si…
-Paul: Oh si claro…Ahora me vas a decir que nunca te has
acostado con alguien.-Yo respire hondo y un poco avergonzada baje la cabeza.-No
me digas que… ¡Eso no es posible! ¿Eres virgen?-Exclamo asombrado, observándome
como si fuera algo de otro mundo.
-(Tn): Pues si… ¿Y qué tiene de malo con que lo sea, ah?
-Paul: No nada, solo que…es extraño.
-(Tn): Ash no empieces.
-Paul: Mmm, pero me supongo que si has tenido novio.
-(Tn): No quiero seguir hablando de eso.
-Paul: ¿Tampoco has tenido novio?
-(Tn): ¡Dije que basta, Paul! Ash eres desesperante de
verdad.
-Paul: Tranquila, solo preguntaba.
-(Tn): No, nunca ¿Y cómo iba a tenerlo? Si primero estuve
encerrada en un internado de niñas por diez años. Segundo, ni siquiera en la
universidad tengo amigos, y lo único que hago es estudiar…No tengo tiempo para
tonterías.
-Paul: Ya entiendo…Entonces…
-(Tn): ¿¡Que!?-Conteste ya muy irritada.
-Paul: Que por eso eres tan amargada. Te hace falta
sexo…-Dijo en un tono pretensioso y burlón.
-(Tn): ¡Paul! ¡Suficiente! ¡El tema se acaba aquí!-Chillé.-Idiota.
El hizo un gesto con las manos levantando los hombros, pero
continuaba riendo. Yo estaba roja como un tomate. ¿Cómo podía ser tan imbécil?
A veces parecía como si con el que estuviese tratando era John, creo que estar
todo el tiempo con ese cretino deterioro en gran parte del ingenuo y tierno
Paul, o tal vez fue la fama…
-(Tn): Juntarte tanto tiempo con el pervertido de John te
afecto.
-Paul: Tal vez, jajajajaja. Fue inevitable, él sabía cómo
divertirse. Aunque ahora que lo pienso…Creo que si me corrompió, un poco…
-(Tn): ¿Un poco?
-Paul: Bueno bueno…Pero tampoco soy tan malo.
-(Tn): ¡Já! Eso espero. –Le guiñe un ojo.
------------------------------------------------------------------------------------------------------
Limpiaba una mesa con la mirada perdida, la verdad no se
daba cuenta de que la mesa ya estaba lista y había dejado caer una taza de té
al piso.
-¡Mierda! No puede ser…-Se agacho para limpiarlo.-Soy una
estúpida.
-X: ¿Qué te sucede Frida? Estas muy distraída últimamente. –Le
dijo una de las camareras que llevaba una cafetera y un pie de manzana en sus
manos, se detuvo y la observarla algo confusa.
-Frida: No, no es nada Aly…Estoy bien.
-Aly: ¿Segura? Recuerda que somos amigas, puedes confiar en
mí.
-Frida: Si Aly. Estoy bien, no hace falta que te preocupes.
-Aly: Mmmm tu ganas. Pero yo sé que debe haber una razón.-Le
dijo alejándose.
Si había una razón, pero ella no quería incomodar a nadie
con sus problemas.
Frida desde aquella noche del concierto se sentía extraña,
abstraída en sus pensamientos; lo que Tino le había dicho, la dejo mas que desconcertada.
Él desapareció, Tino no volvió a ir a la cafetería desde hace unos días; y esto
a ella le extrañaba, se preguntaba si él estaría enojado aun, y no la quería
volver a ver, estaba angustiada pero… ¿Por qué sentía eso, ahora que ya Tino la
molestaba más?
--------------------------------------------------------------------------------------------------
-(Tn): Oye Paul… ¿Te puedo hacer una pregunta?-Le dije
mientras metía un bocado de comida a mi boca. Luego de una larga y
reconfortarle ducha, me encontraba almorzando, Paul en frente, sin apartar la
vista de mí.
-Paul: Ya la hiciste.
-(Tn): Es enserio…
-Paul: Claro, lo que sea.-Levanto una ceja.
-(Tn): No seas pervertido.
-Paul: ¡Pregunta de una vez mujer!
-(Tn): ¿Cómo es que te sientas en el sofá, o en la silla o
en cualquier otro lado y no la traspasas?
-Paul: Solo finjo que lo hago.
-(Tn): ¿Ah? Ósea… ¿Cómo?
-Paul: Si, no es difícil, solo lo hago, como cuando finges
estar dormida. Algo así…
-(Tn): No es lo mismo.
-Paul: Pues no sé qué quieres que te explique entonces, algo
que ni yo mismo entiendo.
-(Tn): Ya ya, te creo…-Hice una pausa-…Esa noche…Cuando
dormía, ¿Tú fuiste quien tocaste mi cabello y mis labios cierto?
-Paul: Emmm si…
-(Tn): Se supone que no puedes hacer eso tampoco. La mayoría
de los espíritus solo se sienten fríos, son vibraciones negativas o positivas, por
eso es que los reconozco y percibo, pero tu…Necesitarías materializar mucha
energía, concentrarla en tu mano y…Es imposible.
-Paul: No claro que no. Recuerda que estoy entre la línea de
una dimensión y otra, así que no estoy completamente muerto; eso me da la
posibilidad de tocarte, y volverme imperceptible cuando yo quiera.
-(Tn): ¿Entonces yo puedo tocarte también?
-Paul: No lo sé, nunca lo eh intentado. Puedes sentirme si,
pero eso cuando yo quiera hacerlo.
-(Tn): Que lío. –Hice una pausa.-Esto de la muerte es muy
frustrante y confuso incluso para mí.
Lleve mi plato al fregadero y me recosté en él.
-(Tn): ¿Puedo hacerlo?
-Paul: ¿Qué cosa?
-(Tn): Tocarte.
-Paul: ¿Ahora?
-(Tn): Si.
-Paul: ¿Pero aquí en la cocina? Mejor vayamos al cuarto, es
más íntimo…-Insinuó con una risa tonta.
-(Tn): Muy bien pero… ¿¡Que!? ¡No Paul, no es a eso a lo que
me refería! Déjate de bromas morbosas.
-Paul: Jajajajajaja. Por un momento pensé que ya eras
divertida.-Le lance una mirada asesina a lo que él volvió a reír.
-(Tn): Olvídalo…-Suspire.-Me tengo que ir al ensayo de la
presentación.
-Paul: Creí que iba a ser yo él que te ayudaría.
-(Tn): Si, pero hasta ahora lo que haces es burlarte de mí.
Además, es obligatorio asistir para todos los concursantes. Y tal vez me
encuentre con Andrew.-Dije lo último con un suspiro de ilusión.
-Paul: Yo me quedare aquí. No quiero ver como coqueteas con
ese imbécil.
-(Tn): Que celoso eres, debo de aclararte que no eres nada
mío para que digas cosas como esas.
-Paul: Ya lo veremos…-Dijo para sí mismo.-Por favor (Tn) es
un tarado sin clase.
-(Tn): ¿Por qué dices eso?
-Paul: (Tn), solo hay que verlo para saber que te engaña con
esa cara de mosco muerto que tiene. Seguro tiene novia y anda de coqueto
contigo.
-(Tn): Si, tú más que nadie debes saber eso ¿No? Te equivocas
Paul. Tú no eres el indicado para darme consejos sobre esto….Hazme un favor y
no me molestes……….Llegare tarde.-Indique abriendo la puerta.
-Paul: Aja…Suerte.-Contesto serio, recostado del sofá.
-(Tn): Gracias.-Susurre.
Cerré la puerta y me fui en el auto al lugar del ensayo.
------------------------------------------------------------------------------------------------------
Practicamos un par de horas con profesores individuales. Fue
divertido, nunca me imaginé hacer algo así, en verdad no sabía cuan buena
podría ser con esto del canto, y el profesor que en verdad era un profesional,
me dijo que si me presentaba con una canción de “Christina Aguilera” ganaría la
competencia, ya que mi voz se prestaba; pero en realidad no era lo que yo
habría de escoger.
Ya el agotamiento
comenzaba a afectar mi criterio, y en un tambaleo me dirigí a mi bolso en busca
de las llaves del auto; además del cansancio del día, tenía en la cabeza todo
el alboroto de Paul, ya comenzaba a ponerse pesado. Me entristecía también no
haber visto a Andrew, creí que él y su grupo no habían clasificado. Admito que
desde aquel día en el que lo conocí, aun recordaba intensamente sus
hipnotizantes ojos verdes. Sin darme cuenta el bolso se me había resbalado de
las manos y ahora me encontraba en el piso recogiendo mis cosas una por una.
-X: Oh linda…Debieras de tener más cuidado, alguien aquí
podría robarte fácilmente.- Me dijo alguien devolviéndome un libro que también
se había salido de mi bolso. Esa voz…Yo arregle todo lo más rápido que pude
colocándome de pie.
-(Tn): Andrew…Si, es que…estoy algo cansada, lo siento, y
gracias.
-X: No hay de que preciosa.- Preciosa…Me ruboricé
ligeramente. Nadie me había dicho así antes. Excepto….Paul, pero él no cuenta.-
¿Así que te gusta el horror?
-(Tn): ¿Disculpa?
-Andrew: Si…Oh, lo digo por el libro…”Prohibido a los
nervioso” de Alfred Hitchcock. Él es muy
bueno, como una antigua versión de Stephen King, me encanta.
-(Tn): ¿De verdad?
-Andrew: Si.
-(Tn): Eso es genial,
no creí que te gustara…
-Andrew: Pues sí.
-(Tn): Si…-Hubo un silencio incómodo. Yo estaba nerviosa, él
también se le notaba algo ansioso.-Así que…Clasificaron. Felicidades.
-Andrew: Si, gracias, igual a ti. Debiste decirme que lo
habías logrado.
-(Tn): ¿Cómo?
-Andrew: Pues llamándome.
-(Tn): Lo siento pero…-Estaba confundida.
-Andrew: ¿No te di mi numero cierto?
-(Tn): No.
-Andrew: Entonces que haces, anótalo…-Yo sonreí mordiéndome
el labio inferior.-Y para que no haya errores, dame el tuyo también.-Excuso.
Saque mi celular inmediatamente, intercambiamos números y
nos quedamos mirando por unos segundos, que parecieron eternos.
-X: Amor, te busque por todas partes, ¿Qué hacías?- Pero de
pronto una chica llego, se notaba algo
molesta, y de inmediato le planto un beso abrazándolo fuertemente. Ella
parecía ignorarme por completo. Yo quede completamente agobiada, confusa e
incómoda con la situación.
-Andrew: Solo conversaba.-Me observo, y esta vez la chica
igual pero lo hacía de arriba abajo con una cara pocos amigos.
-X: ¿Y quién es ella?-Dijo en un tono despectivo.
-Andrew: Se llama (Tn). Es una amiga que hice cuando vine a
la audición. También va a concursar. (Tn) ella es Cosette…mi…
-Cosette: Su novia…-Se adelantó volviéndolo a abrazar.
-Andrew: Si, eso…-Contesto cabizbajo.
Él no se veía muy seguro, pero para mí, había sido más que
decepcionante, aunque debí de haberlo supuesto. Y Paul había tenido razón.
-Cosette: Cariño, no debiste de haberme dejado sola. Ni
menos por estar con otras.
-(Tn): Bueno…Yo ya tengo que irme. Adiós Andrew.-No tenía
ganas de quedarme a charlar, ya era suficiente con verle la cara a esa tipa. Me
di media vuelta buscando que la tierra me tragara.
-Andrew: Espera (Tn). ¿Me llamaras cierto?-Había escuchado
mal, o él enserio había dicho eso en frente de su noviecita. No lo sé, pero
estaba hecha polvo y no hice caso, solo salí del local muy deprisa hacia mi auto.
---------------------------------------------------------------------------------------------------------
-Cosette: ¿Cómo que llamarte? –Ella dirigió su vista muy
furiosa hacia Andrew. Él le dio la espalda dirigiéndose hacia otro lado. –
¡Óyeme Andrew, hazme caso! Dime que te traes con esa.-Le reclamo alzando su
voz. Andrew se colocó en frente de ella.
-Andrew: ¿Quieres calmarte? Es solo una amiga, y su nombre
es (Tn). Por lo menos debiste ser amable…
-Cosette: No Andrew, nada de calmarme.-Contesto alterada.
—Me dejas sola por allí, y de pronto te veo con una cría hablando de lo más
feliz. Andrew, soy tu novia y…
-Andrew: ¡Callate Cosette! ¡Ya estoy harto de ti y de tus
malditos celos! ¡Basta!
-Cosette: Pero, Andrew…
-Andrew: Siempre te comportas así, no importa a donde
vallamos. Cosette, yo también tengo derechos, no puedes prohibirme hablar con
todo el mundo. ¡Eres tan controladora! –Exclamo a regañadientes.-Creo
que…Deberíamos de darnos un tiempo.
-Cosette: ¿¡Que!?
-Andrew: Lo que oíste.
-Cosette: ¡No! Yo te amo Andrew, por eso me comporto así,
pero es que no quiero perderte, yo…Por favor no termines conmigo ahora…Prometo
no volver a hacerlo…Lo juro…-Dijo sollozando.
-Andrew: Ya eh oído eso muchas veces Cosette. Me tienes sin
cuidado….Sera mejor que tomes un bus mañana temprano y vuelvas a Liverpool. –Apretó
los puños irritado.- Aunque para empezar, fue un error haberte traído hasta
aquí…
Cosette lloriqueando con un nudo en la garganta, y todo el
coraje del mundo, hecho a correr, dejando al chico abstraído en sus pensamientos.
Perdiéndose entre esa ciudad iluminada y bajo aquel oscuro cielo, corría
completamente sola.
-----------------------------------------------------------------------------------------------
-(Tn): Ay Paul, tenías razón.-Sollozaba recostándome del sofá
con una manta.
-Paul: ¿Sobre qué?
-(Tn): Lo de Andrew, él…él tiene novia y yo creí…-Comí una
cucharada del enorme frasco de helado que tenía.-Adshgdjkd jhdsh.
-Paul: (Tn) primero trágate el helado, que no te entiendo
nada.
-(Tn): Lo siento…-Me limpie la boca.-Soy una estúpida.
-Paul: No, no lo eres.
-(Tn): Si lo soy. Debiste verlo…Se veía tan interesado en mí,
pero…
-Paul: Lo sé, lo sé.
-(Tn): Ni siquiera te eh contado que sucedió…
-Paul: No hace falta, yo estuve allí.
-(Tn): Entonces, ¿Lo viste todo?
-Paul: Todo…
-(Tn): Creí que estabas enojado conmigo.
-Paul: Lo estaba, pero no podía dejarte sola.
-(Tn): Awww Paul, que lindo eres…
-Paul: Si, y también quería decirte… ¡Te lo dije!-Lo observe
amenazante.
-(Tn): Cambio de opinión, ya no eres lindo.
-Paul: Jajajajajaja.-Un silencio invadió la habitación
iluminada por un foco.
-(Tn): Todos los hombres son unos idiotas, sin excepción.
-Paul: Puede que sí, pero ustedes son las que se ilusionan rápido.
-(Tn): ¿Intentas hacerme sentir bien, o peor?
-Paul: Lo siento… ¡Oye! Ya sé que te hará sonreír.
-(Tn): ¿Tu vestido de Teletubbie?
-Paul: ¿Por qué me disfrazaría de un Teletubbie?
-(Tn): Jajajajaja, no lo sé, pero con solo imaginarlo ya me
divierte.
-Paul: No es gracioso…Hazme caso. Siéntate delante de mí.-Yo
me acomode como él dijo.-Ahora levanta la palma de tu mano, colocándola de
frente…
-(Tn): Listo. ¿Y ahora?
-Paul: Ahora cierra los ojos, y concéntrate en tu mano.
-(Tn): Bien…-Cerré los ojos muy intrigada. Paul hizo lo
mismo que yo.
Sentí como su mano tocaba la mía, era una sensación indescriptible,
pero real, como la de cualquier otro humano. No puede ser, ¡Estaba tocando a un
Beatle!
-Paul: Abre los ojos.-Me dijo en un susurro. Yo lo hice, y
de inmediato sentí unos labios rozar los míos delicadamente. ¿¡Qué rayos acababa
de ocurrir!?
----------------------------------------------------------------------------------------------------
Al llegar del trabajo vio en una silla la chaqueta de su
vecina; decidió ir a devolvérsela, aun no era muy tarde y tal vez la chica se
encontraba preocupada por su prenda.
Ya en la puerta quiso tocar el timbre, pero unas voces de
dentro llamaron su atención… ¿Con quién hablaba? Esto le dio mucha curiosidad,
su vecina no recibía visitas nunca, y la voz no venia del televisor ni de una
radio, era de ella…Y otra entrecortada, que la hizo dudar. Se asomó con sumo
cuidado a la ventana principal que daba a la sala. La luz estaba encendida, y allí
estaba ella, (Tn) conversando con la
nada… ¿Estaría loca? -Que chica más
extraña…-Aun con la incertidumbre, quedo atónita, a ver que alguien apareció
al lado de (Tn) ¡Qué diablos! Todo se ilumino, y esa figura no podía apreciarse
estando borrosa y oscura, pero luego de unos segundos se hizo más clara…
-Frida: No puede ser….
-X: ¡Hey! ¿Quién anda allí?
-------------------------------------------------------------------------------------------------------
Las lágrimas no dejaban de salir, pensaba en que podía haber
hecho mal, él había sido muy duro con ella.
Observando las estrellas desde un gran muelle, el aire se sentía
muy bien, luego de aquella carrera. Cosette intentaba ubicarse, pero no lo
lograba, no conocía bien la enorme ciudad. Estaba tan desesperada que no se percató
por donde iba. Ahora perdida y abatida solo le quedaba esperar sentada en uno
de los bancos, a que alguien pasara y la encontrara.
-Cosette: ¡Ash! ¡Malditos hombres! ¡Ojala todos se pudran en
el infierno!-Grito histéricamente arrojando una piedra al agua.
Volvió a acomodarse en el banco, con la cabeza entre sus
piernas volvió a llorar. Pero en ese momento, una luz brillante invadió el
lugar. Ella con el miedo a flor de piel se lanzó al suelo.
-X: Hola pequeña. No te asustes, por favor.-Le dijo con
naturalidad un chico joven, alto y guapo apareciéndose de la nada luego de
aquel fenómeno de luz, acercándosele más y más.
-Cosette: ¿¡Que eres!? ¿¡Que quieres!? ¿¡Quién eres!? ¡Un
extraterrestre! ¡Ahhhhhhhhhh! ¡Auxilio!-Gritaba desesperada sin saber
exactamente qué hacer.
-X: ¿Extraterrestre? No precisamente…Vengo a cumplir una misión
en la que necesito tu ayuda. Veras…Alguien pronto revelara uno de los secretos mejores
guardados del mundo de la música…Y tengo que evitar eso. Mi nombre es Stuart Sutcliffe...
sábado, 20 de julio de 2013
#3
-Paul: Déjalo ser…
-(Tn): ¿Paul?
-X: ¿Va a cantar o no?-Dijo cortante uno de los jurados
soltando un bufido. Yo asentí con la cabeza.
-(Tn): Yo soy (Tn) Castle, y el tema que interpretare es Let
it be.-Conteste con un tono alto y decidida.
Observe un piano que yacía casi en medio del escenario, cogí
el micrófono colándolo de manera que pudiese ser cómodo cantar y tocar, al
mismo tiempo. Me senté frente a este, comenzando a tocar las notas principales
con ansiedad, me sentí eléctrica, empecé a cantar, solo cantar, sintiendo como
mis dedos se desplazaban con facilidad, los nervios no existían, coloque toda
mi confianza en ese momento. Pude notar como los rostros de los jurados
cambiaban, ahora solo mantenían los ojos muy abiertos, sin ningún movimiento
perceptible.
Termine las últimas notas muy
conmovida. Y luego de un silencio inusual, los aplausos y ovaciones surgieron
espontáneamente de la nada, si no me equivoco, lo había logrado…
----------------------------------------------------------------------------------------------------------
Frida, pensando en cómo le pediría a su jefe que le diera el
resto de la tarde libre, decidió ir al baño para refrescarse un poco.
Recostándose de los lavabos se miraba al espejo aun con la cara empapada.
-Debo de hacer algo con estas ojeras…-Se quejó.
Noto en el piso del lavabo, una
chamarra negra. Al instante recordó a la chica de esa mañana, quien cargaba una
igual, supuso que era de ella y que tal vez se le había caído por error. Como
vivía al lado, decidió guardarla en uno de los lockers de la cafetería, luego
ir a entregársela. Tal vez sería una excusa para conocerla mejor.
-X: Freddy. Ven
inmediatamente.-Le indico su jefe.
-Frida: Es Frida, señor.-Replico
afligida.- ¿Qué sucede?
-X: Como sea…Tendré que llevar a
mi esposa a cenar esta noche, ¡Caray! Aun no sé porque perdí esa condenada
apuesta…En fin…necesito preparar unas cosas, así que no podre cocinar ya que
necesito irme temprano.
-Frida: Y entonces… ¿Quiere que
me quede…a cocinar y atender?-A pesar de tener dos compañeras más que la
ayudaban, no quería perderse el concierto, por lo que ahora la idea se le iba
de las manos.
-X: No, ¿Cómo crees? eso ni
pensarlo.-Exclamo.-Seria un total martirio para ti. Les daré el resto del día
libre… ¡Valla! Y creía ella que su jefe era un “Ogro”, tenía el presentimiento
de que quedaba aun un poco de amabilidad en el hombre.-…Pero mañana domingo
tendrán que venir a trabajar, tenemos que recuperar el dinero de alguna forma…-Agrego
todo cínico, como siempre.
-Frida: Claro señor…-No protesto.
Sabía que era el típico “tacaño aprovechador” y con esa clase de personas no se
podía negociar, quedaba claro, ¡un ogro!
-Tenía que obedecer para no
perder el trabajo, ya que si no era eso, acabaría en algún bar apestoso,
jugándosela con su feminidad y enredada en un tubo, para no morir de hambre en
un callejón….-Dramático el dilema que se repetía todos los días en su mente. -Porque
después de todo, ¿Qué era una chica que no había terminado la secundaria, y que
solo tocar una vieja guitarra, era su única compañía? Para ella,
nada…Simplemente, no era nadie.
Llegue eufórica a mi hogar. Sin tomar en cuenta que ignoraba
por completo a Paul y sus continuas disculpas. No era por hacerme creer la dura,
pero él no media sus palabras, me había hecho sentir mal además.
-Paul: Te dije la canción.
-(Tn): Y agradezco esa ayuda.-Respondí secamente, dándole la
espalda. Mientras organizaba un par de cosas en mi bolso sin tomarlo en cuenta.
-Paul: ¡Pero sigues enojada, ni siquiera me ves!- La sonrisa
de oreja a oreja que cargaba hace unos segundos se deshizo al tener que
enfrentarme con sus molestas protestas.
-(Tn): Exacto, ¿Y tú porque lo crees?
-Paul: ¡Ay, vamos (Tn)! No fue tan malo…
-(Tn): Si, aja… ¿Dónde habré dejado mi chaqueta?-Dije para
mí misma al darme cuenta de que no la traía conmigo… ¡Rayos! Se me está siendo
costumbre esto de olvidarme las cosas. Hablando de eso, tampoco recordaba que
Paul aun me hablaba estando allí.
-Paul: Te resientes por cualquier tontería, a pesar de que
encima, te ayudo.-La gota que derramo el vaso, ¿Enserio? Deseaba en lo más
profundo poder tomarlo del cuello y ahorcarlo, si tan solo hubiese estado vivo,
eso era lo que haría en esos momentos, la ira tomaba control sobre mi cuerpo, y
lo sentía en mis ruborizadas mejillas.
-(Tn): ¿Y sabes? No debiste de haberlo hecho.-Dije aun
molesta.
-Paul: ¿Por qué?-Pregunto ingenuo.
-(Tn): Porque yo no te voy a ayudar a ti…Así que puedes irte
buscando otra “Fenómeno” que se aguate tus insultos, y además, te quiera
ayudar.-Hice énfasis en la palabra fenómeno. -¡Estoy cansada de que las
personas solo me ignoren o me insulten! Ya no más…
Sentía la terrible necesidad de correr y lanzarme desde un
precipicio. Era fatal como me enfurecía, y estaba consciente de que debía
corregirlo. Un psicólogo una vez me dijo que, tenía tendencias suicidas…Y
estaban a punto de ser activadas…
-Paul: Pff….-Soltó un bufido sentándose de un tirón en el
sofá. ¿Cómo hacía para no caer debajo de este? Hubo un silencio -Yo no quiero
que otra persona me ayude, quiero que tú lo seas, (Tn). Lo siento…Yo soy el
fenómeno aquí. -Dijo sereno con algo de tristeza.
Mi estado de ánimo cambio. Y al verlo tan irritado
pidiéndome disculpas, sentí lastima por él. Era cierto…No tenía a nadie más
aquí, estaba desesperado por irse con John, George, sus padres…Y yo solo
pensaba egoístamente.
-(Tn): Paul…-Me dirigí hacia él.
-Paul: Tienes razón….-Mantenía su mirada fija en el suelo.-No
quiero molestarte más con mis problemas, no es tu culpa todo esto, solo te
estorbo, una carga, no soy nadie, literalmente.
Era yo, o también le
había afectado lo último que le dije cuando desapareció -¡Bien, no te necesito, así es
mejor, una carga menos para mí!- Asssh…Me sentía culpable, por un parte.
-(Tn): No…-El volteo a mirarme. Yo fui hacia una repisa, cogí
los LP de The Beatles, y se los lleve. Me coloque a su lado.-Tu eres Paul
McCartney, uno de los músicos más grandes de la historia, todos te aman.-Indique
con una sonrisa. Increíble como sonreía de un momento a otro… ¿Bipolaridad? Tal
vez…
Paul examinaba las portadas.
-Paul: Aman parte del trabajo de ese impostor. –Me observo
contrariado.
-(Tn): Pero él no hubiese sido lo que es ahora, si tú no
hubieras existido, en realidad, lo hacen porque piensan que eres tú…
-Paul: Supongo que tienes razón.-Dijo suspirando. Su vista
se volvió hacia los LP.-Los idiotas lo hicieron.-Sonrió.-Llegaron más alto de
lo que nos pudimos imaginar…Cada álbum es una obra de arte…Lo sé, los eh
escuchado mil veces.-Aunque sonreía, podía notar su voz melancólica con
molestia.
-(Tn): Si, pero… hubiesen sido mejores.
-Paul: ¿De qué hablas?
-(Tn): De que contigo, seguro hubiesen continuado hasta
ahora…No lo sé…Tal vez muchas cosas no hubiesen ocurrido; su separación, la
muerte de John, la enfermedad de George…El destino cambia con los hechos sabes.
-Paul: O simplemente tenía que pasar y ya.
-(Tn): Cierto.
-Paul: Tal vez suene envidioso, pero me alegra que se hayan
separado, no podía continuar así. Aunque la culpa se la debo a Faul…
-(Tn): Jajajaja. ¿A Yoko no?
-Paul: Aaah ¡esa tipa! John era medio ciego, pero siempre
andaba con chicas guapas, era peor que yo, sin embargo su miopía llego al
máximo esta vez…-Diciendo esto no pude evitar soltar una carcajada en la que
Paul me acompaño.- Una vez quise pedirle ayuda, ¿y sabes qué hizo?
-(Tn): ¿Qué hizo?
-Paul: La muy bruja dijo unas palabras extrañas de las que
no entendí nada, y luego de eso ya no pude entrar al departamento de John para
verlo…No me malentiendas, no tengo nada en contra de ella, estaba frita al
igual que él…- Yo reí, Paul sonrió haciendo una pausa.
El ambiente mejoraba. Debo admitirlo, estar enojada con Paul
por más de veinte minutos era un reto.
-Paul: Que lindo es verte sonreír.
-(Tn): ¿Ya vas a empezar?
-Paul: Jajajajaja. Entonces… ¿Me perdonas?
-(Tn): Mmmm….No lo sé. Tal vez luego…-Insinué.
-Paul: Esta bien. Por lo menos me hablas.
-(Tn): Paul…-Musite luego de un silencio.
-Paul: Dime.
-(Tn): Te voy a ayudar. Todo saldrá bien, no te preocupes.
-Paul: Para ti es fácil decirlo. Estás viva, tienes familia
y un motivo por el cual seguir.-Yo baje la cabeza, me entristecía ese tema, de
la familia…-¿Sucede algo?
-(Tn): No es nada.-Dije contrariada, pero mi tristeza era
notoria. Pasaba cada vez que recordaba mi vida en ese aspecto.
-Paul: No seas tan reservada, puedes contarme, soy una tumba…-Índico
burlón. A mí me simpatizo aquella referencia.
-(Tn): Soy hija adoptiva, única. Pero más que eso, mis
padres adoptivos murieron cuando tenía 7 años.
-Paul: Como lo siento por ti… ¿Y luego de eso?
-(Tn): Eres muy curioso.
-Paul: ¡Hey! Tú sabes mi historia, ahora quiero saber la
tuya.
-(Tn): Ya ya…Te contare…-El tema me incomodaba, pero no
quedaba de otra.-Ellos eran empresarios con mucho dinero, su testamento
indicaba que yo sería la única heredera, pues me quisieron como su propia hija;
pero el hermano mayor de mi papa se quedó con la compañía de ellos, aunque no
con el dinero. No quería hacerse cargo de mí, ya que decía que no era nada de
él, molesto con la idea de que nada le tocaba de esa fortuna, me maltrataba, y
al final decidió dejarme en un internado….Cuando cumplí los 18 decidí irme de
ese lugar. Como tenía la mayoría de edad, reclame la herencia. Compre esta
casa, ahora mis estudios los pago con ese dinero, sé que no durara por mucho
tiempo, por eso quiero terminar de una vez por todas comenzar a trabajar. En
consecuencia de eso, estoy sola, en realidad sola.
-Paul: De verdad es muy triste, has sufrido mucho…Más que
yo.
-(Tn): Tranquilo, algún día tendré que superarlo, y creo que
ese día se acerca.-Coloque una sonrisa falsa.
-Paul: ¿No tienes amigos?
-(Tn): No…-Otra vez las estúpidas lágrimas salían, ¿Cómo
podía ser tan débil? Me seque lo más rápido que pude.-Al parecer nadie quiere
involucrarse con una chica que se comunica con espíritus, soy un
fenómeno…-Recordé esa palabra, la última frase se me había escapado, sí que me
traume. -Lo siento…Soy una estúpida.-Hice una pausa, Paul me miraba con compasión. Odiaba que sintieran lastima por
mí, pero en ese momento ya me había quebrado.-A veces….Me gustaría estar
muerta.
-Paul: ¡No, no, no digas eso! ¡Mujer, tu eres maravillosa! Y
quien no quiera ser tu amigo es porque es un completo idiota.-Me sorprendieron
sus palabras. ¿De verdad era Paul McCartney quien me decía eso? Algo en mi
interior se encendió, sin saber cómo describirlo; me limite a intercambiar
miradas.- ¡No vuelvas a decir algo como eso, nunca en tu jodida vida! ¿Me
entendiste? –Lo observaba fijamente, y no evitar enredarse en esos ojos
avellanas era imposible.
Debo admitir que era casi como una alucinación. Que me tenían
dopada en un psiquiátrico, y que solo estaba en un sueño, parte de un trance;
sin embargo yo sentía y sabía que no era así; porque miles de emociones y
sentimientos me atacaban, como nunca por primera vez.
-(Tn): Gracias…-Sonreí a la nada.-
-Paul: ¿Por qué?
-(Tn): Por hacerme sentir viva.-El sonrió. Esa sonrisa
tierna que solo él sabía hacer.
-Paul: De nada, supongo…Aunque no sé muy bien a que te
refieres….
-(Tn): Jajajajaja. Olvídalo.
La verdad que sí, me sentía extraña, sin poder entender nada
de lo que sucedía en aquel momento, en mi cabeza. De pronto aquel chico ya no
era un extraño, o un fantasma común con el que solo intercambiaba algunas
frases, no, era diferente, como tener un amigo…Si eso se sentía el tener uno…no
lo sé. La chica que no creía ni confiaba en nadie estaba desapareciendo. Al
contarle aquello a Paul, fue como quitarse 1000 Kg de encima.
Yo alce la vista hacia el reloj de pared.
-(Tn): ¡Oh cielos! ¡Las cuatro y media pm! Que tarde…
-Paul: ¿Vas a algún lado?
-(Tn): Pues sí. Voy a celebrar mi victoria de esta mañana.
-Paul: ¿Se puede saber a dónde, y con quién?
-(Tn): Deja los celos, galán. Jajajajaja.
-Paul: No son celos, jumm. Dime…
-(Tn): Tranquilo Paulie….Tú vas a ir conmigo.
-Paul: Querida, aunque no me hubiese invitado, igual te seguiría.
-(Tn): Jajajajaja, que tonto eres.
-Paul: ¿A dónde iremos?
-(Tn): Es una sorpresa…
-Paul: No se vale.
-(Tn): Jajajajajaja. Si se vale. Me iré a cambiar. -Dejando
a Paul confundido, me dirigí a la ducha, luego de un rato ya estaba lista.
Baje las escaleras esperando verlo allí.
-(Tn): Lista, vámonos.
-Paul: Que linda te queda esa blusa de Help! Jajajaja. En si
tú haces que se vea mejor de lo que es.-Me mordí el labio.
Traía una blusa blanca pequeña, en ella estaban estampados
ellos (Paul, John, George y ringo) con la posición de Help! Como en su álbum.
Además de un short de jean con la bandera de Londres y unos zapatos converse,
negros.
-(Tn): Que halagador.-Le dije con burla.- Ahora si vámonos, no hay tiempo que perder.-Indique.
Cogí otra chaqueta negra, ya que de seguro haría frio, como es normal en esa
época del año. Abri la puerta muy entusiasmada, Paul reía con mi actitud. Esta
vez, salí conduciendo mi auto, ya que quedaba algo lejos.
Llegaron al concierto, Frida y
Tino se las arreglaban para poder cruzar el tumulto de personas, todas con un
mismo gusto. El ambiente era el más común, como todo concierto. El aire fresco
daba señal de una buena noche; y ellos sin perder un solo segundo, se ubicaron
muy cerca del escenario, de pie, por supuesto.
-Tino: Esto luce bien ¿no?-Le
dijo a la chica colocando una sonrisa amable.
-Frida: Si, esta increíble.
–Dijo secamente.
Se podía notar como disimulaba
la molestia de estar allí con él, aunque fuese solo por una noche. Cuando fue a
buscarla, le sorprendió que supiera donde vivía, ¿Acaso la acosaba? En el
camino no se dirigieron la palabra, más que <<Hola>> Y tan incómodo
como podía estarlo. No le simpatizaba, y el pobre chico por más que intentaba,
no lograba sacarle sonrisa alguna.
-Tino: ¿Quieres una bebida o
algo?
-Frida: Una Coca.
-Tino: O.K ahora vuelvo.-
Relajada de estar sola por un momento, se decidió a no darle mucha importancia
y disfrutar el concierto. Nada podía estropear esa noche.
Ya en el lugar, el escenario estaba casi listo, y la banda,
a punto de salir.
-Paul: Así que esto era no…Un concierto tributo a nosotros
-(Tn): Sip…Pensé que te agradaría.
-Paul: Eh asistido antes a cosas así…Ninguno son muy buenos…
-(Tn): Jajajajaja, nadie podrá ser tan bueno como ustedes,
pero para el que no pudo asistir a un concierto de The Beatles, esto es lo que
nos queda.
Nos ubicamos también muy cerca del escenario, y me coloque
la chaqueta, ya que estaba oscureciendo y el clima estaba muy frio. Contemple
el crepúsculo por un momento, el ruido de los amplificadores se hacía presente,
la gente enloquecía y el lugar se llenaba cada vez más. Los reflectores
salieron disparados, con la hermosa luna llena en el horizonte, daba apertura
el concierto.
-Paul: Espera aquí un momento.
-(Tn): ¿A dónde vas?
-Paul: Ya lo veras…-Me guiño un ojo.
-(Tn): ¿Qué? ¡Paul! ¡Vuel…vuelve!-Muy tarde, ya se había desvanecido
como otras veces, y yo sola, de nuevo…
Allí estaba otra vez él, a su lado. Frida tomo un sorbo de
la gaseosa, aun esperando la presentación. Pero no duro tanto, cuando por fin,
cuatro chicos vestidos con trajes de los Beatles y muy parecidos a estos, se
acomodaban en el escenario con sus respectivos instrumentos. Las chicas
gritaban estruendosamente, aquello era increíble, solo eran dobles. Comenzaron
con la canción “I wanna hold you hand”
-Tino: ¡Wow! Lo hacen muy bien. Sobretodo McCartney.-Señalo
muy asombrado. Ella rodo los ojos con fastidio.
Frida coloco su atención en aquel chico, de verdad que era
idéntico….Su voz, ¿Cómo le salía tan natural? Ella se dio cuenta de este le guiñaba
el ojo y se dirigía siempre hacia un punto en específico del público; se
encontraba en un desnivel notorio, pudiendo visualizar a la chica…. ¡Su vecina!
Sin duda traía mucha curiosidad. La sospecha se hacía cada vez más grande.
Aun no lo podía creer…Paul, era el quien estaba cantando en
el escenario, el verdadero Paul McCartney, ¡Oh! Si tan solo los demás tuvieran
una mínima idea. No sabía cómo, ni porque, pero era él…De alguna forma, había
tomado el cuerpo de aquel muchacho, y ahora…Ahora me dedicaba cada canción, intercambiábamos
miradas, yo lo sabía, era él. Muy sorprendida con todo esto no paraba de
gritar. Un Beatle… ¡Un maravilloso Beatle me cantaba en un escenario frente a
cientos de personas! ¡A mí! A quien nunca nadie dedico canción alguna…Lloraba,
pero esta vez, de felicidad.
-------------------------------------------------------------------------------------------------------
Todo termino. Cada quien se dirigía a su hogar, luego de una
gran noche.
Lo que Frida no descubría aun, y no hablo sobre Paul…Si no por Tino; las
cosas cambiarían luego de que este le llevara a su casa…
Detuvo el auto, pero los seguros continuaban arriba.
-Frida: ¿Qué no vas a abrir?-Dijo algo hostil y fastidiada.
Tino se limitó a guardar silencio; sus facciones inexpresivas.- ¿Qué sucede
contigo? Ashh….Déjame salir.-Chillo muy irritada.
-Tino: No…
-Frida: ¿Qué? Escucha yo…-Pero antes de soltar cualquier
grito fue interrumpida.
-Tino: Frida…Yo no soy estúpido.-Dijo sereno, aunque cierta
molestia en su tono. Ella se limitó a quedarse quieta.-Sé que has intentado
evitarme toda la noche, no solo hoy, si no cada maldita vez que salgo del
trabajo con un maldito permiso, solo para ir a verte a aquella apestosa cafetería.-Su
voz se tornaba alta.- Y de verdad, no sé qué eh hecho para caerte tan mal, es
como si yo te repugnara. Y eso me duele… ¿Sabes? Porque…porque, yo pienso que
eres una chica increíble, única, hermosa, y que tienes mucho talento con la
música; lo sé, sé que no te gusta mostrarlo.-Su vos se entrecorto.- Mientras todos
te ignoraban en los pasillos de la secundaria, yo me recostaba detrás de un
muro, a escucharte, a observarte, siempre me has fascinado. Y discúlpame por
serte tan sincero, pero es que no puedo guardar esto más. Me volveré loco, si
continuas actuando de esa forma tan pedante conmigo…
Y por primera vez, Frida observo aquel brillo misterioso en
los ojos cafés oscuros de aquel chico, y recordó…Enserio él era ese niño tímido
que rondaba cerca de ella cuando sacaba su guitarra entre clases. Temblaba,
algo en su pecho la punzaba. Pero permaneció allí, perdida en su mirada.
-Frida: Yo…yo…No sé qué decir.
-Tino: No hace falta que digas nada. Simplemente quiero que
pienses en eso que te dije…Por ahora solo quiero tu amistad.-En realidad se sentía
abrumada.-Puedes bajar.-Indico Tino abriendo los seguros del auto. Ella bajo despidiéndose,
notando que el chico no se veía para nada contento.
Y dejándola en la fría noche, vio alejarse el auto. Muy
confundida y pensativa. Más que eso…Perpleja, y con culpabilidad, si, se sentía
culpable, y no encontraba de qué.
Intentando ocultar tanta alegría, me dirigí hacia Paul.
Saliendo ya del lugar.
-(Tn): ¿¡Como hiciste eso!? ¿Y por que?
-Paul: Algo que aprendí con el tiempo… ¿Te gusto?
-(Tn): ¿Gustarme? ¡Me fascino! ¡Fue completamente
maravilloso! –Exclame sin ningún temor.- ¡La mejor noche de mi vida!
-Paul: Me alegra saberlo. Lo hice para que me perdonaras, actué como un idiota esta mañana.
-(Tn): Pues, lo lograste galán quedas perdonado, aunque tu siempre actúas como un idiota.
-Paul: Supuse que me dirías algo como eso. ¡Hey! Eras la chica más linda del
publico.-Sonrió.
-(Tn): Ay…No exageres.-Me ruborice un poco.
-Paul: No lo hago, de verdad….
Caminábamos por la noche helada y oscura, hasta mi auto.
-(Tn): ¿Cómo lograste aprenderte las canciones de los demás álbumes?
-Paul: No me subestimes, soy un músico empedernido. Digamos
que todos estos años no solo estuve “espiando chicas” como dices tú…
-(Tn): Jajajajaja. Eso espero… La que más me gusto fue “All
My Loving”…Te veías taaaan sexy.-Dije exagerando. Él soltó una carcajada.
-Paul: Pues, eso es algo que ya lo sé…-Levanto una ceja.
-(Tn): ¡Galán! Jajajajaja. Créeme que estoy tan feliz, que si
estuvieras vivo te abrazaría.
-Paul: Oh….Temprano me querías asesinar, y ahora muestras de
cariño.
-(Tn): ¡Oye! ¿Cómo supiste eso?
-Paul: Lo vi en tus ojos.
-(Tn): ¿Ah, sí?
-Paul: Si…parecías leona en celo….
-(Tn): Uuhhh, gracias por el halago.-Nos limitamos a sonreír.-Y
ahora… ¿Qué ves en mis ojos?-Le dije mirándolo de a ratos. Él se quedó allí,
plasmado, yo sentía como observaba mis pupilas por el rabillo de mi ojo, tenía
cara de idiota…Como siempre.- ¿Paul?
-Paul: Ahh, ¿Si? Oh…Claro, mmm veo que estas cansada…-Contesto
volteando la mirada.
-(Tn): Tienes razón…Ahora me concentrare en el camino. No querrás
morir por segunda vez y ahora yo sea quien pierda la cabeza.
-Paul: No sería mala idea…Vendrías conmigo.-Insinuó, tan pícaro
como él solo.
-(Tn): ¡Paul! Eres un idiota…-Chillé.
Por ahora, las cosas marchaban bien, sentía una nueva conexión
con Paul, no alejándose de la amistad, puedo jurar que en ese momento no me sentía
atraída, o “enamorada”. Solo una relación, una muy extraña relación de amigos
(Lo digo por lo paranormal, el un fantasma, yo humana), y me suponía que él también
lo tomaba así.
Aun no sabía cómo rayos íbamos a solucionar su problema,
pero eso no era importante, aunque en parte era lo esencial. Lo que en realidad
implicaba en el asunto, era que mi vida cambiaba con cada pasar de los días. No
entendía un rábano, pero eso era lo divertido. Y lo bueno, aun no tardaba en
llegar; así como los problemas, todo se avecinaba en conjunto, y claro que según
yo, ya estaba preparada.
-------------------------------------------------------------------------------------------------------
Tarde pero seguro...Disculpenme, problemas técnicos. :c
Quiero agradecerles de todo corazon. :) Ustedes me inspiran a escribir con sus comentarios, de verdad gracias. ¡Son increíbles! Saludos y xoxoxoxox para todas. c:
Suscribirse a:
Entradas (Atom)